@@ -1,6 +1,6 @@
 /* FIGARO'S PASSWORD MANAGER 2 (FPM2)
  * Copyright (C) 2000 John Conneely
- * Copyright (C) 2008,2009 Aleš Koval
+ * Copyright (C) 2008-2010 Aleš Koval
  *
  * FPM is open source / free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -563,3 +563,18 @@ on_clist_main_row_activated            (GtkTreeView     *treeview,
                                         GtkTreeViewColumn *column,
                                         gpointer         user_data);
 
+void
+on_clist_main_columns_changed          (GtkTreeView     *treeview,
+                                        gpointer         user_data);
+
+void
+on_view_menu_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_dblclick_action_combo_changed       (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_startup_search_toggled              (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
