@@ -1,6 +1,6 @@
 /* FIGARO'S PASSWORD MANAGER 2 (FPM2)
  * Copyright (C) 2000 John Conneely
- * Copyright (C) 2008,2009 Aleš Koval
+ * Copyright (C) 2008-2010 Aleš Koval
  *
  * FPM is open source / free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,11 +32,22 @@
 #include <glib/gi18n.h>
 
 /* CONSTANTS */
-#define FPM_NUM_COL 	 3	 /* Number of columns in main CList */
-#define FPM_COL_TITLE	 0
-#define FPM_COL_URL	 1
-#define FPM_COL_USER	 2
-#define FPM_COL_DATA_POINTER	 3
+#define FPM_NUM_COLS 	 8	 /* Number of all available columns */
+#define FPM_DATA_POINTER	 0
+#define FPM_TITLE	 1
+#define FPM_URL		 2
+#define FPM_USER	 3
+#define FPM_PASSWORD	 4
+#define FPM_CATEGORY	 5
+#define FPM_NOTES	 6
+#define FPM_LAUNCHER	 7
+
+enum {  ACTION_RUN_LAUNCHER,
+	ACTION_COPY_USERNAME,
+	ACTION_COPY_PASSWORD,
+	ACTION_COPY_BOTH,
+	ACTION_EDIT_ENTRY
+};
 
 #define FPM_MAX_DOUBLE_CLICK_TIME 0.8 /* In seconds */
 
@@ -85,6 +96,9 @@ typedef struct fpm_launcher_struct
   gint copy_password;
 } fpm_launcher;
 
+extern gchar *columns_title[FPM_NUM_COLS];
+extern GList *columns_order;
+
 typedef struct fpm_ini_struct
 {
     gboolean save_on_quit;
@@ -98,7 +112,7 @@ typedef struct fpm_ini_struct
     gint main_y;
     gint main_width;
     gint main_height;
-    gint columns_width[3];
+    gint columns_width[FPM_NUM_COLS];
     gboolean search_match_case;
     gboolean search_in_title;
     gboolean search_in_url;
@@ -118,6 +132,9 @@ typedef struct fpm_ini_struct
     gint copy_target;
     gboolean clear_target;
     gboolean after_unhide_set_startup_category;
+    gboolean dont_remember_position;
+    gint dblclick_action;
+    gboolean startup_search;
 } fpm_ini;
 
 typedef struct fpm_state_struct
@@ -228,12 +245,6 @@ fpm_quit(void);
 void
 fpm_init(char* opt_file_name, int tray_on_startup);
 
-/*void
-fpm_select(gchar* text, gboolean use_clipboard);
-
-void
-fpm_select_password(fpm_data* data, gboolean use_clipboard);
-*/
 void
 fpm_double_click(fpm_data* data);
 
@@ -274,7 +285,7 @@ void fpm_prefs_save_launcher(void);
 
 void fpm_debug(gchar* msg);
 
-void lock_fpm_file1(gchar* glb_filename);
+void lock_fpm_file(gchar* glb_filename);
 
 void unlock_fpm_file1(void);
 
@@ -313,3 +324,40 @@ char *fpm_get_combo_entry(GtkWidget *win, gchar *entry_name);
 gboolean fpm_valid_edit_data();
 
 gboolean fpm_is_launcher_in_category(fpm_launcher *launcher, gchar *category);
+
+void on_clist_main_columns_changed          (GtkTreeView     *treeview,
+                                    	     gpointer         user_data);
+
+void fpm_view_modify_column(gint type, gboolean active);
+
+void fpm_clist_set_data(fpm_data *data, GtkTreeModel *list_store, GtkTreeIter iter);
+
+void fpm_middle_dblclick(fpm_data *data);
+
+void fpm_clipboard_init(fpm_data *data, gint selection, gboolean is_password, gboolean multi_select);
+
+void fpm_populate_combo_box(GtkComboBox *combo_box, gchar *active_item);
+
+void fpm_copy_target_combo(GtkComboBox *combo_box, gint selection);
+
+void fpm_unlock();
+
+void fpm_switch_view_category(gchar *category);
+
+void fpm_launcher_add();
+
+void fpm_launcher_remove(fpm_launcher *launcher);
+
+void fpm_launcher_remove_all();
+
+void fpm_launcher_show(fpm_launcher *launcher);
+
+void fpm_launcher_populate_combo_box(gint launcher_idx);
+
+gboolean fpm_launcher_search(gchar *title);
+
+void unlock_fpm_file(void);
+
+void fpm_dirty(gboolean active);
+
+void fpm_sensitive_menu(gboolean active);
